<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Správa uživatelů</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Správa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Přidat nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Přidat uživatelský účet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Znovu zadejte heslo pro nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>Potvrďte heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>Username of new user</source>
        <translation>Jméno nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <source>User login name:</source>
        <translation>Přihlašovací jméno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Enter username of new user</source>
        <translation>Zadejte Jméno nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <location filename="../mainwindow.ui" line="462"/>
        <source>username</source>
        <translation>uživatelské jméno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Password for new user</source>
        <translation>Heslo pro nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User password:</source>
        <translation>Uživatelské heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Enter password for new user</source>
        <translation>Zadejte heslo pro nového uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <source>password</source>
        <translation>heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Confirm user password:</source>
        <translation>Potvrďte uživatelské heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Delete User Account</source>
        <translation>Smazat uživatelský účet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Select user</source>
        <translation>Vybrat uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="339"/>
        <location filename="../mainwindow.ui" line="1426"/>
        <source>Select user to delete</source>
        <translation>Vybrat uživatele k smazání</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>User to delete:</source>
        <translation>Smazat uživatele:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Taktéž smazat domovskou složku uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Delete user home directory</source>
        <translation>Smazat domovskou složku uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="386"/>
        <source>Rename User Account</source>
        <translation>Přejmenovat uživatelský účet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <location filename="../mainwindow.ui" line="560"/>
        <source>Select user to modify:</source>
        <translation>Vybrat uživatele k provedení změn:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>New user name:</source>
        <translation>Nové uživatelské jméno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>Change User Password</source>
        <translation>Změnte uživatelské heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>new password</source>
        <translation>nové heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Confirm new password:</source>
        <translation>Potvrďte nové heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>confirm new password</source>
        <translation>potvrďte nové heslo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>New user password:</source>
        <translation>Nové uživatelské heslo:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Repair a user configuration</source>
        <translation>Opravit uživatelské nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Modify User Account</source>
        <translation>Upravit uživatelský účet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Select user to repair</source>
        <translation>Vybrat uživatele k opravě</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="1435"/>
        <source>User to change:</source>
        <translation>Změnit uživatele:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Restore Defaults</source>
        <translation>Obnovit výchozí nastavení</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="728"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Obnovit nastavení prohlížeče na MX výchozí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Konfigurace Mozilla (Firefox nebo Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="737"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Obnovit členství v skupinách na MX výchozí</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Group memberships</source>
        <translation>Členství v skupině</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Change Autologin Settings</source>
        <translation>Změnit nastavení automatického přihlašování</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Log in automatically</source>
        <translation>Přihlašovat automaticky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>Require password to log in</source>
        <translation>Při přihlášení požadovat heslo </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>Copy/Sync</source>
        <translation>Kopírovat/Synchronizovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="818"/>
        <source>Copy Between Desktops</source>
        <translation>Kopírovat mezi plochami</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="845"/>
        <location filename="../mainwindow.ui" line="912"/>
        <source>Select desktop to copy from</source>
        <translation>Vyberte plochu ze které se bude kopírovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="858"/>
        <source>Select to only copy files</source>
        <translation>Vyberte pouze zkopírovat soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="861"/>
        <source>Copy only</source>
        <translation>Kopírovat pouze</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="877"/>
        <location filename="../mainwindow.ui" line="890"/>
        <source>Select desktop to copy to</source>
        <translation>Vyberte plochu ze které se bude kopírovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="899"/>
        <source>Copy to:</source>
        <translation>Kopírovat kam:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="921"/>
        <source>Copy from:</source>
        <translation>Kopírovat odkud:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="934"/>
        <source>Select to copy and then delete differences</source>
        <translation>Zvolte k kopírování a potom smažte rozdíly</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="937"/>
        <source>Sync</source>
        <translation>Synchronizovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="983"/>
        <source>Select to copy/sync Shared</source>
        <translation>Vyberte zkopírovat/synchronizovat Sdílené</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="986"/>
        <source>Shared folder</source>
        <translation>Sdílená složka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="999"/>
        <source>Select to copy/sync entire home</source>
        <translation>Vyberte zkopírovat/synchronizovat veškerý obsah Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Entire home</source>
        <translation>Veškerý obsah Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1018"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Vyberte zkopírovat/synchronizovat nastavení prohlížeče</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1021"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Konfigurace Mozilla (Firefox nebo Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1034"/>
        <source>Select to copy/sync Documents</source>
        <translation>Vyberte zkopírovat/synchronizovat Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1037"/>
        <source>Documents folder</source>
        <translation>Složka Dokumenty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>What to copy/sync:</source>
        <translation>Vyberte co zkopírovat/synchronizovat:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1060"/>
        <source>Progress</source>
        <translation>Progres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1090"/>
        <location filename="../mainwindow.ui" line="1106"/>
        <source>Status of the changes</source>
        <translation>Stav změn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1109"/>
        <source>Status:</source>
        <translation>Stav:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1125"/>
        <source>Progress of the changes</source>
        <translation>Progres změn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1162"/>
        <source>Add/Remove Groups</source>
        <translation>Přidat/Smazat skupiny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1174"/>
        <source>Add Group</source>
        <translation>Přidat skupinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1252"/>
        <source>Group name:</source>
        <translation>Název skupiny:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1201"/>
        <source>Enter name of new group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1207"/>
        <source>groupname</source>
        <translation>název skupiny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Delete Group</source>
        <translation>Smazat skupinu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group to delete:</source>
        <translation type="vanished">Skupina k smazání:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1371"/>
        <source>Group Membership</source>
        <translation>Členství v skupině</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1497"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Skupiny ve kterých je uživatel členem (skupiny změníte vybráním/odvybráním jednotlivých políček):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1468"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1641"/>
        <source>Apply any changes</source>
        <translation>Uložit všechny změny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1573"/>
        <source>Cancel any changes then quit</source>
        <translation>Zrušit všechny změny a ukončit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1220"/>
        <source>Create a user-level group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1349"/>
        <source>Select group to delete:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1356"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1576"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1624"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1627"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <location filename="../mainwindow.cpp" line="154"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="180"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="715"/>
        <location filename="../mainwindow.cpp" line="869"/>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="981"/>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="986"/>
        <source>none</source>
        <translation>není</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="875"/>
        <location filename="../mainwindow.cpp" line="883"/>
        <source>browse...</source>
        <translation>prohledat...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="206"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Nastavení uživatele bude nyní opraveno. Prosím zavřete všechny aplikace. Po dokočení  opravy se odhlašte se nebo restartujte počítač. Jste si jistí, že chcete začít s opravou?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>User group membership was restored.</source>
        <translation>Členství ve skupině bylo obnoveno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Mozilla settings were reset.</source>
        <translation>Nastavení Mozilly bylo resetováno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Autologin options</source>
        <translation>Možnosti automatického přihlašování</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Bylo deaktivováno automatické přihlašování pro účet &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="255"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Bylo aktivováno automatické přihlašování pro účet &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Musíte vybrat cílové umístnění. Nemůžete kopírovat na plochu uživatele, pod kterým jste přihlášení.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Před kopírováním zavřete všchny aplikace. Ujistěte se, že v cílovém umístnění je dostatek místa pro umístnění kopírovaných souborů. Kopírování mezi plochami může přepsat nebo smazat soubory nebo nastavení v cílové ploše. Jste si jistí, že chcete pokračovat?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Synchronizing desktop...</source>
        <translation>Synchronizuji plochu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copying desktop...</source>
        <translation>Kopíruji plochu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Uživatelské jméno musí být dlouhé alespoň 2 znaky. Prosím zvolte delší jméno a pokračujte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Je nám líto, jméno je již použito. Prosím vyberte jiné jméno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Záznamy hesla se neshodují. Zkuste to znovu prosím.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Heslo uživatele musí být dlouhé alespoň 2 znaky. Prosím zvolte delší jméno a pokračujte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>The user was added ok.</source>
        <translation>Přidán nový uživatel.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>Přidání uživatele zlyhalo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Password successfully changed.</source>
        <translation>Heslo bylo změněno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Failed to change password.</source>
        <translation>Heslo nebylo změněno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Toto je nevratná změna. Jste si jistí, že chcete smazat uživatele %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>The user has been deleted.</source>
        <translation>Uživavel by odstraněn.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Failed to delete the user.</source>
        <translation>Smazání uživatele zlyhalo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Název skupiny musí být dlouhý alespoň 2 znaky. Prosím zvolte delší název a pokračujte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Název skupiny musí být vytvořen z malých písmen
a nesmí obsahovat speciální znaky nebo mezery.
Prosím zvolte jiný název a pokračujte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Je nám líto, jméno skupiny je již použito. Prosím vyberte jiné jméno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="449"/>
        <source>The system group was added ok.</source>
        <translation>Nová skupina přidána.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Failed to add the system group.</source>
        <translation>Přidání skupiny zlyhalo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Toto je nevratná změna. Jste si jistí, že chcete smazat skupinu %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Group: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The group has been deleted.</source>
        <translation>Skupina byla odstraněna.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>Failed to delete the group.</source>
        <translation>Smazání skupiny zlyhalo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The groups have been deleted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>The changes have been applied.</source>
        <translation>Změny byly provedeny.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Failed to apply group changes</source>
        <translation>Provedení změn skupiny zlyhalo.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>The selected user name is currently in use.</source>
        <translation>Vybrané uživatelské jméno je nyní používáno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Pro přejmenování tohoto uživatele se prosím odhlašte a přihlašte se zpět pod jiným účtem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="525"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Jméno uživatele musí být vytvořeno z malých písmen
a nesmí obsahovat speciální znaky nebo mezery.
Prosím zvolte jiné jméno a pokračujte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="534"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Je nám líto, toto jméno je již v systému použito. Prosím vyberte jiné jméno.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Nepodařilo se přejmenovat uživatele. Ujistěte se, že uživatel není přihlášen, případně proveďte restart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>The user was renamed.</source>
        <translation>Uživatel byl přejmenován.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <location filename="../mainwindow.cpp" line="605"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synchronizování plochy...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Copying desktop...ok</source>
        <translation>Kopírování plochy...OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synchronizování plochy...zlyhalo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <source>Copying desktop...failed</source>
        <translation>Kopírování plochy...zlyhalo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Confirmation</source>
        <translation>Potvrzení</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="835"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Jednoduchý konfigurační nástroj uživatelů pro MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>%1 License</source>
        <translation>Licence %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>%1 Help</source>
        <translation>Nápověda %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Select folder to copy to</source>
        <translation>Vyberte složku do které se bude kopírovat</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Spuštěno pod účtem root-a, odhlašte se a přihlašte jako bězný uživatel.</translation>
    </message>
</context>
</TS>
